package com.fyber.mediation;

import android.app.Activity;
import com.fyber.mediation.admob.AdMobMediationAdapter;
import com.fyber.mediation.applovin.AppLovinMediationAdapter;
import com.fyber.mediation.chartboost.ChartboostMediationAdapter;
import com.fyber.mediation.facebook.FacebookMediationAdapter;
import com.fyber.mediation.unityads.UnityAdsMediationAdapter;
import com.fyber.mediation.vungle.VungleMediationAdapter;
import com.fyber.utils.FyberLogger;
import com.fyber.utils.testsuite.b;
import java.lang.InterruptedException;
import java.lang.Object;
import java.lang.String;
import java.util.HashMap;
import java.util.Map;
import java.util.concurrent.ExecutionException;
import java.util.concurrent.Future;

public final class MediationAdapterStarter {
  public static final String FYBER_STARTED = "FYBER_STARTED";

  public static final String ADAPTER_VERSION = "ADAPTER_VERSION";

  private static final String TAG = "MediationAdapterStarter";

  public static AdaptersListener adaptersListener;

  private static boolean startAppLovin(final Activity activity, final Map<String, Object> configs, final Map<String, MediationAdapter> map) {
    boolean adapterStartedSuccessfully = false;
    try {
      MediationAdapter adapter = new AppLovinMediationAdapter();
      configs.put(ADAPTER_VERSION, "7.3.1-r1");
      FyberLogger.d(TAG, "Starting adapter AppLovin with version 7.3.1-r1");
      adapterStartedSuccessfully = adapter.startAdapter(activity, configs);
      if (adapterStartedSuccessfully) {
        FyberLogger.d(TAG, "Adapter AppLovin with version 7.3.1-r1 was started successfully");
        map.put("applovin", adapter);
      } else {
        FyberLogger.d(TAG, "Adapter AppLovin with version 7.3.1-r1 was not started successfully");
      }
    } catch (Throwable throwable) {
      FyberLogger.e(TAG, "Exception occurred while loading adapter AppLovin with version 7.3.1-r1 - " + throwable.getCause());
    }
    return adapterStartedSuccessfully;
  }

  private static boolean startVungle(final Activity activity, final Map<String, Object> configs, final Map<String, MediationAdapter> map) {
    boolean adapterStartedSuccessfully = false;
    try {
      MediationAdapter adapter = new VungleMediationAdapter();
      configs.put(ADAPTER_VERSION, "4.0.3-r2");
      FyberLogger.d(TAG, "Starting adapter Vungle with version 4.0.3-r2");
      adapterStartedSuccessfully = adapter.startAdapter(activity, configs);
      if (adapterStartedSuccessfully) {
        FyberLogger.d(TAG, "Adapter Vungle with version 4.0.3-r2 was started successfully");
        map.put("vungle", adapter);
      } else {
        FyberLogger.d(TAG, "Adapter Vungle with version 4.0.3-r2 was not started successfully");
      }
    } catch (Throwable throwable) {
      FyberLogger.e(TAG, "Exception occurred while loading adapter Vungle with version 4.0.3-r2 - " + throwable.getCause());
    }
    return adapterStartedSuccessfully;
  }

  private static boolean startApplifier(final Activity activity, final Map<String, Object> configs, final Map<String, MediationAdapter> map) {
    boolean adapterStartedSuccessfully = false;
    try {
      MediationAdapter adapter = new UnityAdsMediationAdapter();
      configs.put(ADAPTER_VERSION, "2.1.0-r1");
      FyberLogger.d(TAG, "Starting adapter Applifier with version 2.1.0-r1");
      adapterStartedSuccessfully = adapter.startAdapter(activity, configs);
      if (adapterStartedSuccessfully) {
        FyberLogger.d(TAG, "Adapter Applifier with version 2.1.0-r1 was started successfully");
        map.put("applifier", adapter);
      } else {
        FyberLogger.d(TAG, "Adapter Applifier with version 2.1.0-r1 was not started successfully");
      }
    } catch (Throwable throwable) {
      FyberLogger.e(TAG, "Exception occurred while loading adapter Applifier with version 2.1.0-r1 - " + throwable.getCause());
    }
    return adapterStartedSuccessfully;
  }

  private static boolean startAdMob(final Activity activity, final Map<String, Object> configs, final Map<String, MediationAdapter> map) {
    boolean adapterStartedSuccessfully = false;
    try {
      MediationAdapter adapter = new AdMobMediationAdapter();
      configs.put(ADAPTER_VERSION, "15.0.0-r2");
      FyberLogger.d(TAG, "Starting adapter AdMob with version 15.0.0-r2");
      adapterStartedSuccessfully = adapter.startAdapter(activity, configs);
      if (adapterStartedSuccessfully) {
        FyberLogger.d(TAG, "Adapter AdMob with version 15.0.0-r2 was started successfully");
        map.put("admob", adapter);
      } else {
        FyberLogger.d(TAG, "Adapter AdMob with version 15.0.0-r2 was not started successfully");
      }
    } catch (Throwable throwable) {
      FyberLogger.e(TAG, "Exception occurred while loading adapter AdMob with version 15.0.0-r2 - " + throwable.getCause());
    }
    return adapterStartedSuccessfully;
  }

  private static boolean startFacebookAudienceNetwork(final Activity activity, final Map<String, Object> configs, final Map<String, MediationAdapter> map) {
    boolean adapterStartedSuccessfully = false;
    try {
      MediationAdapter adapter = new FacebookMediationAdapter();
      configs.put(ADAPTER_VERSION, "4.28.1-r1");
      FyberLogger.d(TAG, "Starting adapter FacebookAudienceNetwork with version 4.28.1-r1");
      adapterStartedSuccessfully = adapter.startAdapter(activity, configs);
      if (adapterStartedSuccessfully) {
        FyberLogger.d(TAG, "Adapter FacebookAudienceNetwork with version 4.28.1-r1 was started successfully");
        map.put("facebookaudiencenetwork", adapter);
      } else {
        FyberLogger.d(TAG, "Adapter FacebookAudienceNetwork with version 4.28.1-r1 was not started successfully");
      }
    } catch (Throwable throwable) {
      FyberLogger.e(TAG, "Exception occurred while loading adapter FacebookAudienceNetwork with version 4.28.1-r1 - " + throwable.getCause());
    }
    return adapterStartedSuccessfully;
  }

  private static boolean startChartboost(final Activity activity, final Map<String, Object> configs, final Map<String, MediationAdapter> map) {
    boolean adapterStartedSuccessfully = false;
    try {
      MediationAdapter adapter = new ChartboostMediationAdapter();
      configs.put(ADAPTER_VERSION, "7.0.1-r2");
      FyberLogger.d(TAG, "Starting adapter Chartboost with version 7.0.1-r2");
      adapterStartedSuccessfully = adapter.startAdapter(activity, configs);
      if (adapterStartedSuccessfully) {
        FyberLogger.d(TAG, "Adapter Chartboost with version 7.0.1-r2 was started successfully");
        map.put("chartboost", adapter);
      } else {
        FyberLogger.d(TAG, "Adapter Chartboost with version 7.0.1-r2 was not started successfully");
      }
    } catch (Throwable throwable) {
      FyberLogger.e(TAG, "Exception occurred while loading adapter Chartboost with version 7.0.1-r2 - " + throwable.getCause());
    }
    return adapterStartedSuccessfully;
  }

  public static Map<String, MediationAdapter> startAdapters(final Activity activity, final Map<String, Map<String, Object>> configs) {
    Map<String, MediationAdapter> map = new HashMap<>();
    getConfigsForAdapter(configs, "AppLovin").put(FYBER_STARTED, startAppLovin(activity, getConfigsForAdapter(configs, "AppLovin"), map));
    getConfigsForAdapter(configs, "Vungle").put(FYBER_STARTED, startVungle(activity, getConfigsForAdapter(configs, "Vungle"), map));
    getConfigsForAdapter(configs, "Applifier").put(FYBER_STARTED, startApplifier(activity, getConfigsForAdapter(configs, "Applifier"), map));
    getConfigsForAdapter(configs, "AdMob").put(FYBER_STARTED, startAdMob(activity, getConfigsForAdapter(configs, "AdMob"), map));
    getConfigsForAdapter(configs, "FacebookAudienceNetwork").put(FYBER_STARTED, startFacebookAudienceNetwork(activity, getConfigsForAdapter(configs, "FacebookAudienceNetwork"), map));
    getConfigsForAdapter(configs, "Chartboost").put(FYBER_STARTED, startChartboost(activity, getConfigsForAdapter(configs, "Chartboost"), map));
    return map;
  }

  public static int getAdaptersCount() {
    return 6;
  }

  private static Map<String, Object> getConfigsForAdapter(Map<String, Map<String, Object>> configs, String adapter) {
    Map<String, Object> config = configs.get(adapter.toLowerCase());
    if (config == null) {
      config = new HashMap();
      configs.put(adapter.toLowerCase(), config);
    }
    return config;
  }

  private static Map<String, Map<String, Object>> getConfigs(final Future<Map<String, Map<String, Object>>> futureConfig) {
    Map<String, Map<String, Object>> configs = MediationConfigProvider.getConfigs();
    Map<String, Map<String, Object>> runtimeConfigs = MediationConfigProvider.getRuntimeConfigs();
    configs = mergeConfigs(runtimeConfigs, configs);
    try {
      if (futureConfig != null) {
        Map<String, Map<String, Object>> serverConfigs = futureConfig.get();
        configs = mergeConfigs(configs, serverConfigs);
      }
    } catch (InterruptedException | ExecutionException e) {
      FyberLogger.e(TAG, "Exception occurred", e);
    }
    return configs;
  }

  private static Map<String, Map<String, Object>> mergeConfigs(final Map<String, Map<String, Object>> fromConfigs, final Map<String, Map<String, Object>> intoConfigs) {
    if (fromConfigs != null && !fromConfigs.isEmpty()) {
      for (Map.Entry<String, Map<String, Object>> entry: fromConfigs.entrySet()) {
        String network = entry.getKey();
        Map<String, Object> adapterFromConfigs = entry.getValue();
        Map<String, Object> adapterIntoConfigs = intoConfigs.get(network);
        if (adapterIntoConfigs == null) {
          adapterIntoConfigs = new HashMap<>();
        }
        if (adapterFromConfigs != null) {
          adapterIntoConfigs.putAll(adapterFromConfigs);
        }
        intoConfigs.put(network, adapterIntoConfigs);
      }
    } else {
      FyberLogger.d(TAG, "There were no configurations to override");
    }
    return intoConfigs;
  }

  public static Map<String, MediationAdapter> startAdapters(final Activity activity, final Future<Map<String, Map<String, Object>>> future) {
    Map<String, Map<String, Object>> configs = getConfigs(future);
    Map<String, MediationAdapter> adapters = startAdapters(activity, configs);
    if (adaptersListener != null) {
      adaptersListener.startedAdapters(adapters.keySet(), configs);
    }
    b.a(adapters, configs);
    return adapters;
  }
}
